@@ -56,15 +56,13 @@ sub at { shift->find(@_)->[0] }
 sub attrs {
   my $self = shift;
 
-  # Not a tag
-  return {} if (my $tree = $self->tree)->[0] eq 'root';
-
   # Hash
-  my $attrs = $tree->[2];
+  my $tree = $self->tree;
+  my $attrs = $tree->[0] eq 'root' ? {} : $tree->[2];
   return $attrs unless @_;
 
   # Get
-  return $attrs->{$_[0]} unless @_ > 1 || ref $_[0];
+  return $attrs->{$_[0]} // '' unless @_ > 1 || ref $_[0];
 
   # Set
   %$attrs = (%$attrs, %{ref $_[0] ? $_[0] : {@_}});
@@ -133,12 +131,12 @@ sub namespace {
   my $self = shift;
 
   # Prefix
-  return if (my $current = $self->tree)->[0] eq 'root';
+  return '' if (my $current = $self->tree)->[0] eq 'root';
   my $prefix = $current->[1] =~ /^(.*?)\:/ ? $1 : '';
 
   # Walk tree
   while ($current) {
-    return if $current->[0] eq 'root';
+    return '' if $current->[0] eq 'root';
     my $attrs = $current->[2];
 
     # Namespace for prefix
@@ -147,11 +145,13 @@ sub namespace {
     }
 
     # Namespace attribute
-    elsif (defined $attrs->{xmlns}) { return $attrs->{xmlns} || undef }
+    elsif (defined $attrs->{xmlns}) { return $attrs->{xmlns} }
 
     # Parent
     $current = $current->[3];
   }
+
+  return '';
 }
 
 sub parent {
@@ -280,7 +280,7 @@ sub type {
   my ($self, $type) = @_;
 
   # Not a tag
-  return if (my $tree = $self->tree)->[0] eq 'root';
+  return '' if (my $tree = $self->tree)->[0] eq 'root';
 
   # Get
   return $tree->[1] unless $type;
@@ -318,7 +318,7 @@ sub _add {
 }
 
 sub _elements {
-  my $e = shift;
+  return [] unless my $e = shift;
   return [@$e[($e->[0] eq 'root' ? 1 : 4) .. $#$e]];
 }
 
@@ -391,7 +391,7 @@ sub _trim {
   my ($e, $trim) = @_;
 
   # Disabled
-  return 0 unless $trim = defined $trim ? $trim : 1;
+  return 0 unless $e && ($trim = defined $trim ? $trim : 1);
 
   # Detect "pre" tag
   while ($e->[0] eq 'tag') {
