@@ -2,10 +2,9 @@ package Mojo::Template;
 use Mojo::Base -base;
 
 use Carp 'croak';
-use IO::Handle;
 use Mojo::ByteStream;
 use Mojo::Exception;
-use Mojo::Util qw(decode encode);
+use Mojo::Util qw(decode encode slurp);
 
 # "If for any reason you're not completely satisfied, I hate you."
 has [qw(auto_escape compiled)];
@@ -295,9 +294,7 @@ sub render_file {
 
   # Slurp file
   $self->name($path) unless defined $self->{name};
-  croak qq{Can't open template "$path": $!} unless open my $file, '<', $path;
-  my $tmpl = '';
-  while ($file->sysread(my $buffer, 131072, 0)) { $tmpl .= $buffer }
+  my $tmpl = slurp $path;
 
   # Decode and render
   if (my $encoding = $self->encoding) {
@@ -307,18 +304,6 @@ sub render_file {
   return $self->render($tmpl, @_);
 }
 
-sub render_file_to_file {
-  my ($self, $spath, $tpath) = (shift, shift, shift);
-  my $output = $self->render_file($spath, @_);
-  return ref $output ? $output : $self->_write_file($tpath, $output);
-}
-
-sub render_to_file {
-  my ($self, $tmpl, $path) = (shift, shift, shift);
-  my $output = $self->render($tmpl, @_);
-  return ref $output ? $output : $self->_write_file($path, $output);
-}
-
 sub _trim {
   my ($self, $line) = @_;
 
@@ -343,18 +328,6 @@ sub _trim {
   }
 }
 
-sub _write_file {
-  my ($self, $path, $output) = @_;
-
-  # Encode and write to file
-  croak qq{Can't open file "$path": $!} unless open my $file, '>', $path;
-  $output = encode $self->encoding, $output if $self->encoding;
-  croak qq{Can't write to file "$path": $!}
-    unless defined $file->syswrite($output);
-
-  return;
-}
-
 1;
 
 =head1 NAME
@@ -403,6 +376,14 @@ designed specifically for all those small tasks that come up during big
 projects. Like preprocessing a configuration file, generating text from
 heredocs and stuff like that.
 
+See L<Mojolicious::Guides::Rendering> for information on how to generate
+content with the L<Mojolicious> renderer.
+
+=head1 SYNTAX
+
+For all templates L<strict>, L<warnings> and Perl 5.10 features are
+automatically enabled.
+
   <% Perl code %>
   <%= Perl expression, replaced with result %>
   <%== Perl expression, replaced with XML escaped result %>
@@ -414,8 +395,6 @@ heredocs and stuff like that.
   %# Comment line, treated as "<%# line =%>"
   %% Replaced with "%", useful for generating templates
 
-=head2 Escaping
-
 Escaping behavior can be reversed with the C<auto_escape> attribute, this is
 the default in L<Mojolicious> C<.ep> templates for example.
 
@@ -437,14 +416,10 @@ And a backslash in front of a newline can be escaped with another backslash.
   in multiple\\
   lines
 
-=head2 Trimming
-
 Whitespace characters around tags can be trimmed with a special tag ending.
 
   <%= All whitespace characters around this expression will be trimmed =%>
 
-=head2 Blocks
-
 You can capture whole template blocks for reuse later with the C<begin> and
 C<end> keywords.
 
@@ -455,8 +430,6 @@ C<end> keywords.
   <%= $block->('Baerbel') %>
   <%= $block->('Wolfgang') %>
 
-=head2 Indentation
-
 Perl lines can also be indented freely.
 
   % my $block = begin
@@ -466,8 +439,6 @@ Perl lines can also be indented freely.
   %= $block->('Baerbel')
   %= $block->('Wolfgang')
 
-=head2 Arguments
-
 L<Mojo::Template> templates work just like Perl subs (actually they get
 compiled to a Perl sub internally). That means you can access arguments simply
 via C<@_>.
@@ -476,8 +447,6 @@ via C<@_>.
   % my $x = shift;
   test 123 <%= $foo %>
 
-=head2 Exceptions
-
 Templates get compiled to Perl code internally, this can make debugging a bit
 tricky. But L<Mojo::Template> will return L<Mojo::Exception> objects that
 stringify to error messages with context.
@@ -708,21 +677,6 @@ Render template.
 
 Render template file.
 
-=head2 C<render_file_to_file>
-
-  my $exception = $mt->render_file_to_file('/tmp/foo.mt', '/tmp/foo.txt');
-  my $exception
-    = $mt->render_file_to_file('/tmp/foo.mt', '/tmp/foo.txt', @args);
-
-Render template file to another file.
-
-=head2 C<render_to_file>
-
-  my $exception = $mt->render_to_file($template, '/tmp/foo.txt');
-  my $exception = $mt->render_to_file($template, '/tmp/foo.txt', @args);
-
-Render template to a file.
-
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
