@@ -1,5 +1,5 @@
 package Mojolicious::Command::generate::lite_app;
-use Mojo::Base 'Mojo::Command';
+use Mojo::Base 'Mojolicious::Command';
 
 has description => "Generate Mojolicious::Lite application.\n";
 has usage       => "usage: $0 generate lite_app [NAME]\n";
@@ -58,12 +58,13 @@ Mojolicious::Command::generate::lite_app - Lite app generator command
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Command::generate::lite_app> is a application generator.
+L<Mojolicious::Command::generate::lite_app> generate fully functional
+L<Mojolicious::Lite> applications.
 
 =head1 ATTRIBUTES
 
 L<Mojolicious::Command::generate::lite_app> inherits all attributes from
-L<Mojo::Command> and implements the following new ones.
+L<Mojolicious::Command> and implements the following new ones.
 
 =head2 C<description>
 
@@ -82,7 +83,7 @@ Usage information for this command, used for the help screen.
 =head1 METHODS
 
 L<Mojolicious::Command::generate::lite_app> inherits all methods from
-L<Mojo::Command> and implements the following new ones.
+L<Mojolicious::Command> and implements the following new ones.
 
 =head2 C<run>
 
