@@ -97,8 +97,8 @@ sub register {
       my $expires = $args->{expires} || 0;
       delete $memorize{$name}
         if exists $memorize{$name}
-          && $expires > 0
-          && $memorize{$name}{expires} < time;
+        && $expires > 0
+        && $memorize{$name}{expires} < time;
 
       # Memorized
       return $memorize{$name}{content} if exists $memorize{$name};
@@ -135,8 +135,10 @@ Mojolicious::Plugin::DefaultHelpers - Default helpers plugin
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::DefaultHelpers> is a collection of renderer helpers for
-L<Mojolicious>. This is a core plugin, that means it is always enabled and its
-code a good example for learning to build new plugins.
+L<Mojolicious>.
+
+This is a core plugin, that means it is always enabled and its code a good
+example for learning to build new plugins, you're welcome to fork it.
 
 =head1 HELPERS
 
@@ -201,7 +203,7 @@ Dump a Perl data structure using L<Data::Dumper>.
   % extends 'blue';
   % extends 'blue', title => 'Blue!';
 
-Extend a template, all arguments get merged into the stash.
+Extend a template. All additional values get merged into the C<stash>.
 
 =head2 C<flash>
 
@@ -222,7 +224,8 @@ only available in the partial template.
   % layout 'green';
   % layout 'green', title => 'Green!';
 
-Render this template with a layout, all arguments get merged into the stash.
+Render this template with a layout. All additional values get merged into the
+C<stash>.
 
 =head2 C<memorize>
 
@@ -266,7 +269,7 @@ Alias for L<Mojolicious::Controller/"stash">.
   % title 'Welcome!', foo => 'bar';
   %= title
 
-Page title, all arguments get merged into the stash.
+Page title. All additional values get merged into the C<stash>.
 
 =head2 C<url_for>
 
